Documentation
¶
Index ¶
- func AmOrPMFormatter(hour int, minute int, second int) string
- func ArrayIncludes(array []string, value string) bool
- func ArrayReplace(text string, old []string, new []string) string
- func Date() string
- func DayFormatter(day int) string
- func Debug(message ...any)
- func Error(message ...any)
- func Fatal(message ...any)
- func FormatString(str string, value []string) string
- func Info(message ...any)
- func IntToString(value int) string
- func Log(state string) func(...any)
- func LogSorter(v ...any) string
- func MonthFormatter(month time.Month) string
- func ToLower(value string) string
- func Warning(message ...any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AmOrPMFormatter ¶
amOrPMFormatter formats and returns the time in a 12-hour clock format with AM/PM suffix. It takes hour, minute, and second as input parameters and returns the formatted time string.
func ArrayIncludes ¶
func DayFormatter ¶
dayFormatter takes a day of the month as an integer and returns a string in the format [number] [suffix]. The suffix is determined by the day of the month, following the standard English rules for ordinal numbers. For example, the 1st, 2nd, 3rd, 21st, 22nd, and 23rd will have the suffixes "st", "nd", "rd", "st", "nd", and "rd", respectively. All other days of the month will have the suffix "th".
func FormatString ¶
func IntToString ¶
func MonthFormatter ¶
monthFormatter takes a time.Month and returns a string of the full name of the month, such as "January" or "February".
Types ¶
This section is empty.